/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.blogger.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Page.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Blogger API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Page extends GenericJson {

  /**
   * The author of this Page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Author author;

  /**
   * Data about the blog containing this Page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Blog blog;

  /**
   * The body content of this Page, in HTML.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String content;

  /**
   * The identifier for this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of this entity. Always blogger#page
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * RFC 3339 date-time when this Page was published.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * The API REST URL to fetch this resource from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The title of this entity. This is the name displayed in the Admin user interface.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * RFC 3339 date-time when this Page was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The URL that this Page is displayed at.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String url;

  /**
   * The author of this Page.
   * The value returned may be {@code null}.
   */
  public Author getAuthor() {
    return author;
  }

  /**
   * The author of this Page.
   * The value set may be {@code null}.
   */
  public Page setAuthor(Author author) {
    this.author = author;
    return this;
  }

  /**
   * Data about the blog containing this Page.
   * The value returned may be {@code null}.
   */
  public Blog getBlog() {
    return blog;
  }

  /**
   * Data about the blog containing this Page.
   * The value set may be {@code null}.
   */
  public Page setBlog(Blog blog) {
    this.blog = blog;
    return this;
  }

  /**
   * The body content of this Page, in HTML.
   * The value returned may be {@code null}.
   */
  public String getContent() {
    return content;
  }

  /**
   * The body content of this Page, in HTML.
   * The value set may be {@code null}.
   */
  public Page setContent(String content) {
    this.content = content;
    return this;
  }

  /**
   * The identifier for this resource.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The identifier for this resource.
   * The value set may be {@code null}.
   */
  public Page setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of this entity. Always blogger#page
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of this entity. Always blogger#page
   * The value set may be {@code null}.
   */
  public Page setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * RFC 3339 date-time when this Page was published.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * RFC 3339 date-time when this Page was published.
   * The value set may be {@code null}.
   */
  public Page setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value set may be {@code null}.
   */
  public Page setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * The title of this entity. This is the name displayed in the Admin user interface.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of this entity. This is the name displayed in the Admin user interface.
   * The value set may be {@code null}.
   */
  public Page setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * RFC 3339 date-time when this Page was last updated.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * RFC 3339 date-time when this Page was last updated.
   * The value set may be {@code null}.
   */
  public Page setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The URL that this Page is displayed at.
   * The value returned may be {@code null}.
   */
  public String getUrl() {
    return url;
  }

  /**
   * The URL that this Page is displayed at.
   * The value set may be {@code null}.
   */
  public Page setUrl(String url) {
    this.url = url;
    return this;
  }

  /**
   * The author of this Page.
   */
  public static final class Author extends GenericJson {

    /**
     * The display name.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String displayName;

    /**
     * The identifier of the Page creator.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The page author's avatar.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Image image;

    /**
     * The URL of the Page creator's Profile page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * The display name.
     * The value returned may be {@code null}.
     */
    public String getDisplayName() {
      return displayName;
    }

    /**
     * The display name.
     * The value set may be {@code null}.
     */
    public Author setDisplayName(String displayName) {
      this.displayName = displayName;
      return this;
    }

    /**
     * The identifier of the Page creator.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The identifier of the Page creator.
     * The value set may be {@code null}.
     */
    public Author setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The page author's avatar.
     * The value returned may be {@code null}.
     */
    public Image getImage() {
      return image;
    }

    /**
     * The page author's avatar.
     * The value set may be {@code null}.
     */
    public Author setImage(Image image) {
      this.image = image;
      return this;
    }

    /**
     * The URL of the Page creator's Profile page.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * The URL of the Page creator's Profile page.
     * The value set may be {@code null}.
     */
    public Author setUrl(String url) {
      this.url = url;
      return this;
    }

    /**
     * The page author's avatar.
     */
    public static final class Image extends GenericJson {

      /**
       * The page author's avatar URL.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String url;

      /**
       * The page author's avatar URL.
       * The value returned may be {@code null}.
       */
      public String getUrl() {
        return url;
      }

      /**
       * The page author's avatar URL.
       * The value set may be {@code null}.
       */
      public Image setUrl(String url) {
        this.url = url;
        return this;
      }

    }
  }

  /**
   * Data about the blog containing this Page.
   */
  public static final class Blog extends GenericJson {

    /**
     * The identifier of the blog containing this page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The identifier of the blog containing this page.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The identifier of the blog containing this page.
     * The value set may be {@code null}.
     */
    public Blog setId(String id) {
      this.id = id;
      return this;
    }

  }

}
